# -*- coding: utf-8 -*-
from pyramid_oereb.lib.config import Config
from pyramid_oereb.standard.xtf_import.util import parse_string, parse_multilingual_text, get_tag


class LegendEntry(object):

    TAG_LEGEND = 'Legende'
    TAG_LEGEND_ENTRY = 'OeREBKRMtrsfr_V1_1.Transferstruktur.LegendeEintrag'
    TAG_SYMBOL = 'Symbol'
    TAG_SYMBOL_BIN = 'BINBLBOX'
    TAG_LEGEND_TEXT = 'LegendeText'
    TAG_TYPE_CODE = 'ArtCode'
    TAG_TYPE_CODE_LIST = 'ArtCodeliste'
    TAG_SUB_THEME = 'SubThema'
    TAG_OTHER_THEME = 'WeiteresThema'

    def __init__(self, session, model, topic_code):
        self._session = session
        self._model = model
        self._topic_code = topic_code

    def parse(self, view_service):  # pragma: no cover
        language = Config.get('default_language')
        for element in view_service:
            if get_tag(element) == self.TAG_LEGEND:
                count = 1
                for legend_entry in element:
                    if get_tag(legend_entry) == self.TAG_LEGEND_ENTRY:
                        sub_theme = parse_string(legend_entry, self.TAG_SUB_THEME)
                        if sub_theme is not None:
                            sub_theme = {language: sub_theme}
                        instance = self._model(
                            id='{0}.legende.{1}'.format(view_service.attrib['TID'], count),
                            symbol=self._parse_symbol(legend_entry, self.TAG_SYMBOL),
                            legend_text=parse_multilingual_text(
                                legend_entry,
                                self.TAG_LEGEND_TEXT
                            ),
                            type_code=parse_string(legend_entry, self.TAG_TYPE_CODE),
                            type_code_list=parse_string(
                                legend_entry,
                                self.TAG_TYPE_CODE_LIST
                            ),
                            topic=self._topic_code,
                            sub_theme=sub_theme,
                            other_theme=parse_string(legend_entry, self.TAG_OTHER_THEME),
                            view_service_id=view_service.attrib['TID']
                        )
                        self._session.add(instance)
                        count += 1

    def _parse_symbol(self, element, prop):
        for p in element:
            if get_tag(p) == prop:
                for binblbox in p:
                    if get_tag(binblbox) == self.TAG_SYMBOL_BIN:
                        return binblbox.text
        return None



# -*- coding: utf-8 -*-

from pyramid_oereb.lib.config import Config


class LawStatusRecord(object):
    """
    Law status record.
    """

    def __init__(self, code, text):
        """
        Create a new law status record.

        Args:
            code (str or unicode): The code of the law status. It must be "inForce" or "runningModifications"
                every other value will raise an error.
            text (dict of unicode): The multilingual law status description.
        """
        if code != u'inForce' and code != u'runningModifications':
            raise AttributeError('wrong code for law status was deliverd. Only "inForce" or '
                                 '"runningModifications" are allowed. Value was {0}'.format(code))

        self.code = code
        self.text = text

    @classmethod
    def from_config(cls, code):
        """
        Create a new law status record using the translations specified in the configuration.

        Args:
            code (str or unicode): The code of the law status. It must be "inForce" or "runningModifications"
                every other value will raise an error.

        Returns:
            pyramid_oereb.lib.records.law_status.LawStatusRecord: The created law status record.
        """
        return LawStatusRecord(code, Config.get_law_status_translations(code))



# -*- coding: utf-8 -*-
from pyramid_oereb.standard.xtf_import.util import parse_ref, parse_article_numbers


class DocumentReference(object):

    TAG_SOURCE = 'Ursprung'
    TAG_TARGET = 'Hinweis'
    TAG_ARTICLE_NUMBERS = 'ArtikelNr'

    def __init__(self, session, model):
        self._session = session
        self._model = model

    def parse(self, document_reference):  # pragma: no cover
        source = parse_ref(document_reference, self.TAG_SOURCE)
        target = parse_ref(document_reference, self.TAG_TARGET)
        instance = self._model(
            id='{0}-{1}'.format(source, target),
            document_id=source,
            reference_document_id=target,
            article_numbers=parse_article_numbers(
                document_reference,
                self.TAG_ARTICLE_NUMBERS
            )
        )
        self._session.add(instance)
